/*
 * The fmc-tdc (a.k.a. FmcTdc1ns5cha) library test program.
 *
 * Copyright (c) 2014-2018 CERN
 * Author: Tomasz Włostowski <tomasz.wlostowski@cern.ch>
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#include "test-common.h"

char git_version[] = "git version: " GIT_VERSION;

void fmctdc_term_print(struct fmctdc_board *brd, unsigned int channel)
{
	int err;
	unsigned int enable;

	err = fmctdc_termination_get(brd, channel, &enable);
	if (err < 0) {
		fprintf(stderr,
			"channel %d: cannot read termination status\n",
			channel);
		return ;
	}

	printf("channel %d: 50 Ohm termination is %s\n",
	       channel, enable ? "on" : "off");
}

int main(int argc, char **argv)
{
	init(argc, argv);

	check_help(argc, argv, 2,
		   "[-h] [-V] <device> <channel> [on/off]",
		   "Enables or disables the 50 Ohm termination of a given input channel.\n"
		   "No on/off command returns the current state of termination resistor.",
		   "");;

	open_board(argv[1]);

	if (argc == 2) {
		int i;
		for (i = FMCTDC_CH_1; i <= FMCTDC_CH_LAST; i++)
			fmctdc_term_print(brd, i);
		return 0;
	}

	int channel = atoi(argv[2]);

	if (channel < FMCTDC_CH_1 || channel > FMCTDC_CH_LAST) {
		fprintf(stderr, "%s: invalid channel.\n", argv[0]);
		return -1;
	}

	if (argc >= 4) {
		int term_on;
		if (!strcasecmp(argv[3], "on"))
			term_on = 1;
		else if (!strcasecmp(argv[3], "off"))
			term_on = 0;
		else {
			fprintf(stderr, "%s: invalid command.\n", argv[0]);
			return -1;
		}

		if (fmctdc_termination_set(brd, channel, term_on) < 0) {
			fprintf(stderr, "%s: error setting termination: %s\n",
				argv[0], strerror(errno));
			return -1;
		}
	}

	fmctdc_term_print(brd, channel);

	return 0;
}
